@@ -13,4 +13,8 @@ menu_items = (
         link='plugins:inventory_monitor:contract_list',
         link_text='Contracts'
     ),
+    PluginMenuItem(
+        link='plugins:inventory_monitor:invoice_list',
+        link_text='Invoices'
+    ),
 )
